%% The Blood Trail of the Veto: A Forecast of the Risk of Extreme Massacres in Syria
% Adam Scharpf (University of Mannheim)
% Gerald Schneider & Anna Nh (both University of Konstanz)
% Aaron Clauset (University of Colorado, Santa Fe Institute)


%% Notes for Replicating In-Sample Prediction Results
% The analysis was done in MatLab. The files for
% implementing the statistical methods used in the paper can be found on
% Aaron Clauset's website under:
% http://tuvalu.santafe.edu/~aaronc/powerlaws/ 
% http://tuvalu.santafe.edu/~aaronc/rareevents/

% We used a customized version of the plotting functions. For replicating
% Figures 3.1 and 3.2 you need to replace the 'plplot_pred' and the 
% 'pleplot_pred' commands with the original ones.
% For saving the figures on your hard drive, please replace >> ... << with 
% path to a folder of choice.

% For replicating our out-of sample forecasts please contact Aaron
% Clauset.


%% Setting working paths 
% Replace >> ... << with the folder path containing Aaron Clauset's
% M-files and the data (in .mat-format).
path(path,'...')                           
path(path,'...')


%% Estimating Power Law for Syria (Shuhada, Province-Day Level)

% Loading data set
load 'SySh_ProvDayData_03032013';

% Estimating power law parameters
[Alpha, XMin, L] = plfit(death,'range',[1.001:0.001:5.001]);
NTail=sum(death>=XMin);

% Plotting power law 
h=plplot_pred(death, XMin, Alpha);
saveas(gcf,'...\Syria_Shuhada_ProvDay','emf');

% Assessing variance of power law parameters
[AlphaVar, XMinVar, NTailVar] = plvar(death,'range',[1.001:0.001:5.001]);

% Assessing power law fit
[PVal, gof] = plpva(death, XMin,'range',[1.001:0.001:5.001]);


%% In-Sample Predictions for Syria (Shuhada database, Province-Day Level)

% *In-Sample Prediction for 250 Killed Civilians (Fixed xmin=44)*
[p250fix q250fix s250fix] = plout(death,'range',[3.00:0.01:4.50],'boots',10000,'draws',1000,'cat',250,'xmin',44);
AlphaFixPred250=mean(s250fix(:,1))
XMinFixPred250=mean(s250fix(:,2))
NTailFixPred250=mean(s250fix(:,3))
CIFix250=prctile(s250fix(:,4),[5 95])

h=pleplot_pred(death, s250fix);
saveas(gcf,'...\Syria_Shuhada_ProvDay_FixPred250','emf');


% *In-Sample Prediction for 364 Killed Civilians (Fixed xmin=44)*
[p364fix q364fix s364fix] = plout(death,'range',[3.00:0.01:4.50],'boots',10000,'draws',1000,'cat',364,'xmin',44);
AlphaFixPred364=mean(s364fix(:,1))
XMinFixPred364=mean(s364fix(:,2))
NTailFixPred364=mean(s364fix(:,3))
CIFix364=prctile(s364fix(:,4),[5 95])

h=pleplot_pred(death, s364fix);
saveas(gcf,'...\Syria_Shuhada_ProvDay_FixPred364','emf');


% *In-Sample Prediction for 500 Killed Civilians (Fixed xmin=44)*
[p500fix q500fix s500fix] = plout(death,'range',[3.00:0.01:4.50],'xmin',44,'boots',10000,'draws',1000,'cat',500);
AlphaFixPred500=mean(s500fix(:,1))
XMinFixPred500=mean(s500fix(:,2))
NTailFixPred500=mean(s500fix(:,3))
CIFix500=prctile(s500fix(:,4),[5 95])

h=pleplot_pred(death, s500fix);
saveas(gcf,'...\Syria_Shuhada_ProvDay_FixPred500','emf');


% *In-Sample Prediction for 750 Killed Civilians (Fixed xmin=44)*
[p750fix q750fix s750fix] = plout(death,'range',[3.00:0.01:4.50],'boots',10000,'draws',1000,'cat',750,'xmin',44);
AlphaFixPred750=mean(s750fix(:,1))
XMinFixPred750=mean(s750fix(:,2))
NTailFixPred750=mean(s750fix(:,3))
CIFix750=prctile(s750fix(:,4),[5 95])

h=pleplot_pred(death, s750fix);
saveas(gcf,'...\Syria_Shuhada_ProvDay_FixPred750','emf');

% *In-Sample Prediction for 1000 Killed Civilians (Fixed xmin=44)*
[p1000fix q1000fix s1000fix] = plout(death,'range',[3.00:0.01:4.50],'boots',10000,'draws',1000,'cat',1000,'xmin',44); 
AlphaFixPred1000=mean(s1000fix(:,1))
XMinFixPred1000=mean(s1000fix(:,2))
NTailFixPred1000=mean(s1000fix(:,3))
CIFix1000=prctile(s1000fix(:,4),[5 95])

h=pleplot_pred(death, s1000fix);
saveas(gcf,'...\Syria_Shuhada_ProvDay_FixPred1000','emf');

